@@ -516,27 +516,37 @@ get_chorizon_from_SDA <- function(WHERE = NULL, duplicates = FALSE,
   }
 
   q.chorizon <- paste("
-  SELECT",
-  if (duplicates == FALSE) {"DISTINCT"}
-  , "hzname, hzdept_r, hzdepb_r, texture, texcl, fragvol_l, fragvol_r, fragvol_h, sandtotal_l, sandtotal_r, sandtotal_h, silttotal_l, silttotal_r, silttotal_h, claytotal_l, claytotal_r, claytotal_h, om_l, om_r, om_h, dbthirdbar_l, dbthirdbar_r, dbthirdbar_h, ksat_l, ksat_r, ksat_h, awc_l, awc_r, awc_h, lep_r, sar_r, ec_r, cec7_r, sumbases_r, ph1to1h2o_l, ph1to1h2o_r, ph1to1h2o_h, caco3_l, caco3_r, caco3_h, kwfact, kffact, c.cokey, ch.chkey
-
+  SELECT", if (duplicates == FALSE) {"DISTINCT"}
+  , "hzname, hzdept_r, hzdepb_r, texture, texcl, lieutex,
+     fragvol_l, fragvol_r, fragvol_h, 
+     sandtotal_l, sandtotal_r, sandtotal_h, 
+     silttotal_l, silttotal_r, silttotal_h, 
+     claytotal_l, claytotal_r, claytotal_h,
+     om_l, om_r, om_h, 
+     dbthirdbar_l, dbthirdbar_r, dbthirdbar_h,
+     ksat_l, ksat_r, ksat_h,  
+     awc_l, awc_r, awc_h, 
+     lep_r, sar_r, ec_r, cec7_r, sumbases_r, 
+     ph1to1h2o_l, ph1to1h2o_r, ph1to1h2o_h,
+     caco3_l, caco3_r, caco3_h, 
+     kwfact, kffact, c.cokey, ch.chkey
   FROM legend l INNER JOIN
-       mapunit mu ON mu.lkey = l.lkey INNER JOIN",
-  if (duplicates == FALSE) { paste("
+       mapunit mu ON mu.lkey = l.lkey",
+  if (duplicates == FALSE) { paste(" INNER JOIN
   (SELECT MIN(nationalmusym) nationalmusym2, MIN(mukey) AS mukey2
    FROM mapunit
    GROUP BY nationalmusym) AS mu2 ON mu2.mukey2 = mu.mukey
   ")
-  } else { paste("
+  } else { paste(" INNER JOIN
    (SELECT nationalmusym, mukey
     FROM mapunit) AS mu2 ON mu2.mukey = mu.mukey
-   ")},
+   ")
+  },
   "INNER JOIN
    component    c    ON c.mukey      = mu.mukey   LEFT JOIN
    chorizon     ch   ON ch.cokey     = c.cokey    LEFT OUTER JOIN
-   chtexturegrp chtg ON chtg.chkey   = ch.chkey
-                     AND rvindicator = 'YES'      LEFT OUTER JOIN
-   chtexture    cht  ON cht.chtgkey  = chtg.chkey
+   chtexturegrp chtg ON chtg.chkey   = ch.chkey AND rvindicator = 'Yes' RIGHT JOIN
+   chtexture    cht  ON cht.chtgkey  = chtg.chtgkey
 
    LEFT OUTER JOIN
        (SELECT SUM(fragvol_l) fragvol_l, SUM(fragvol_r) fragvol_r, SUM(fragvol_h) fragvol_h, ch2.chkey
@@ -556,15 +566,15 @@ get_chorizon_from_SDA <- function(WHERE = NULL, duplicates = FALSE,
   # hacks to make R CMD check --as-cran happy:
   metadata <- NULL
   # load local copy of metadata
-  load(system.file("data/metadata.rda", package="soilDB")[1])
+  load(system.file("data/metadata.rda", package = "soilDB")[1])
 
   # transform variables and metadata
   if (!is.null(d.chorizon) && nrow(d.chorizon) > 0){
     d.chorizon <- within(d.chorizon, {
       nationalmusym = NULL
       texture = tolower(texture)
-      if (getOption("stringsAsFactors", default = FALSE)) {
-        texcl = factor(tolower(texcl), levels = metadata[metadata$ColumnPhysicalName == "texcl", "ChoiceName"])
+      if (getOption("stringsAsFactors", default = FALSE) || getOption("soilDB.NASIS.DomainsAsFactor", default = FALSE)) {
+        texcl = factor(texcl, levels = metadata[metadata$ColumnPhysicalName == "texcl", "ChoiceLabel"])
       }
       if (droplevels == droplevels && is.factor(texcl)) {
         texcl = droplevels(texcl)
